package org.vamsas.client.simpleclient;

import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.nio.channels.FileLock;

/**
 * transient object representing a file lock
 * 
 * 
 * @author jimp
 * 
 */

public class Lock {
  FileLock lock = null;
  /**
   * creates a valid Lock (test with <method>isLocked</method>)
   * if a lock could be obtained for <param>lockfile</param>
   * @param lockfile
   */
  public Lock(java.io.File lockfile) {
    // try and get a lock.
    lock = null;

    try {
      if (!lockfile.exists())
        if (!lockfile.createNewFile()) {
          return;
        }

      lock = new FileOutputStream(lockfile).getChannel().tryLock();
    } catch (FileNotFoundException e) {
      System.err.println("Error! Couldn't create a lockfile at "
          + lockfile.getAbsolutePath());
      e.printStackTrace();
    } catch (IOException e) {
      System.err.println("Error! Problems with IO when creating a lock on "
          + lockfile.getAbsolutePath());
      e.printStackTrace();
    }
  }

  boolean isLocked() {
    if (lock != null && lock.isValid()) {
      return true;
    }
    return false;
  }

  /* Explicitly release lock (probably don't need to do this!)
   * @see java.lang.Object#finalize()
   */
  protected void finalize() throws Throwable {
    if (lock!=null)
      lock.release();
    super.finalize();
  }
  
}
